@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,6 +17,7 @@
 
 #include "configurepluginslistwidgettest.h"
 #include "../configurepluginslistwidget.h"
+#include "kdepimtest_layout.h"
 #include <QTest>
 #include <QTreeWidget>
 #include <QVBoxLayout>
@@ -36,7 +37,7 @@ void ConfigurePluginsListWidgetTest::shouldHaveDefaultValue()
 
     QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->margin(), 0);
+    KdepimTestLayout::checkContentsMargins(0, mainLayout);
 
     QTreeWidget *mListWidget = w.findChild<QTreeWidget *>(QStringLiteral("listwidget"));
     QVERIFY(mListWidget);
