@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -104,7 +104,7 @@ void MigrateApplicationFilesTest::shouldMigrateFolders()
     QStringList files;
     files << QStringLiteral("file1") << QStringLiteral("file2");
     const QString xdgDatahome = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + folderName;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -126,7 +126,7 @@ void MigrateApplicationFilesTest::shouldMigrateFolders()
     QVERIFY(migrate.checkIfNecessary());
 
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QVERIFY(QFile(xdgDatahome + file).exists());
     }
 }
@@ -147,7 +147,7 @@ void MigrateApplicationFilesTest::shouldNotMigrateFoldersIfAlreadyDone()
     QStringList files;
     files << QStringLiteral("file1") << QStringLiteral("file2");
     const QString xdgDatahome = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + folderName;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -171,7 +171,7 @@ void MigrateApplicationFilesTest::shouldNotMigrateFoldersIfAlreadyDone()
     migrate.insertMigrateInfo(info);
 
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QVERIFY(!QFile(xdgDatahome + file).exists());
     }
 }
@@ -192,7 +192,7 @@ void MigrateApplicationFilesTest::shouldMigrateFoldersWithSubFolders()
     QStringList files;
     files << QStringLiteral("file1") << QStringLiteral("file2");
     const QString xdgDatahome = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + folderName;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -208,7 +208,7 @@ void MigrateApplicationFilesTest::shouldMigrateFoldersWithSubFolders()
     QDir().mkpath(appsPathSubfolder);
     QVERIFY(QDir(appsPathSubfolder).exists());
     const QString xdgDatahomeSubfolder = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + subFolder;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPathSubfolder + QLatin1Char('/') + file;
@@ -232,7 +232,7 @@ void MigrateApplicationFilesTest::shouldMigrateFoldersWithSubFolders()
     migrate.setCurrentConfigVersion(1);
 
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QVERIFY(QFile(xdgDatahome + file).exists());
         QVERIFY(QFile(xdgDatahomeSubfolder + file).exists());
     }
@@ -255,7 +255,7 @@ void MigrateApplicationFilesTest::shouldNotMigrateIfAlreadyDone()
 
     QStringList files;
     files << QStringLiteral("file1") << QStringLiteral("file2");
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -283,7 +283,7 @@ void MigrateApplicationFilesTest::shouldNotMigrateIfAlreadyDone()
     //We have a current version == 3 => don't migrate old info.
     migrate.setCurrentConfigVersion(3);
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QVERIFY(!QFile(xdgDatahome + file).exists());
     }
 }
@@ -305,7 +305,7 @@ void MigrateApplicationFilesTest::shouldMigrateFiles()
 
     QStringList files;
     files << QStringLiteral("file1") << QStringLiteral("file2");
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -330,7 +330,7 @@ void MigrateApplicationFilesTest::shouldMigrateFiles()
 
     QVERIFY(migrate.checkIfNecessary());
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QVERIFY(QFile(xdgDatahome + file).exists());
     }
 }
@@ -357,7 +357,7 @@ void MigrateApplicationFilesTest::shouldMigrateFilesWithPattern()
     filesMustNotBeMigrated << QStringLiteral("file1") << QStringLiteral("file2");
 
     files << filesMustBeMigrated << filesMustNotBeMigrated;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : qAsConst(files)) {
         QFile fooFile(QLatin1String(MIGRATION_DATA_DIR) + QLatin1Char('/') + file);
         QVERIFY(fooFile.exists());
         const QString storedConfigFilePath = appsPath + QLatin1Char('/') + file;
@@ -380,10 +380,10 @@ void MigrateApplicationFilesTest::shouldMigrateFilesWithPattern()
 
     QVERIFY(migrate.checkIfNecessary());
     QVERIFY(migrate.start());
-    Q_FOREACH (const QString &file, filesMustBeMigrated) {
+    for (const QString &file : qAsConst(filesMustBeMigrated)) {
         QVERIFY(QFile(xdgDatahome + file).exists());
     }
-    Q_FOREACH (const QString &file, filesMustNotBeMigrated) {
+    for (const QString &file : qAsConst(filesMustNotBeMigrated)) {
         QVERIFY(!QFile(xdgDatahome + file).exists());
     }
 }
