@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ QString GoogleTranslator::resultTranslate() const
     return mResult;
 }
 
-QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(KComboBox *from)
+QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(QComboBox *from)
 {
     QMap<QString, QMap<QString, QString> > listLanguage;
 
