@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -217,7 +217,7 @@ void TranslatorWidget::init()
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(2);
+    layout->setContentsMargins(2, 2, 2, 2);
     QHBoxLayout *hboxLayout = new QHBoxLayout;
     QToolButton *closeBtn = new QToolButton(this);
     closeBtn->setObjectName(QStringLiteral("close-button"));
