@@ -23,11 +23,9 @@
 #include <kcombobox.h>
 #include "pimcommon_export.h"
 
-namespace PimCommon
-{
-
-/** @short A KComboBox, which minimum size hint can be really small */
-class PIMCOMMON_EXPORT MinimumComboBox: public KComboBox
+namespace PimCommon {
+/** @short A QComboBox, which minimum size hint can be really small */
+class PIMCOMMON_EXPORT MinimumComboBox : public KComboBox
 {
     Q_OBJECT
 public:
@@ -36,7 +34,6 @@ public:
 protected:
     QSize minimumSizeHint() const override;
 };
-
 }
 
 #endif
