@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -75,7 +75,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
     setAddDialogLabel(addDialogLabel);
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     QHBoxLayout *hlay = new QHBoxLayout(this);
-    hlay->setMargin(0);
+    hlay->setContentsMargins(0, 0, 0, 0);
 
     d->mListBox = new QListWidget(this);
 
