@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -38,7 +38,7 @@ void ContentTypeWidgetTest::shouldHaveDefaultValue()
     PimCommon::ContentTypeWidget widget;
     QLabel *label = widget.findChild<QLabel *>(QStringLiteral("contenttypewidgetlabel"));
     QVERIFY(label);
-    KComboBox *combo = widget.findChild<KComboBox *>(QStringLiteral("contentcombobox"));
+    QComboBox *combo = widget.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     QVERIFY(combo);
     QVERIFY(combo->count() > 0);
     QCOMPARE(widget.currentIndex(), 0);
@@ -47,7 +47,7 @@ void ContentTypeWidgetTest::shouldHaveDefaultValue()
 void ContentTypeWidgetTest::shouldChangeComboBoxIndex()
 {
     PimCommon::ContentTypeWidget contentType;
-    KComboBox *combo = contentType.findChild<KComboBox *>(QStringLiteral("contentcombobox"));
+    QComboBox *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     for (int i = 0; i < combo->count(); ++i) {
         contentType.setCurrentIndex(i);
         QCOMPARE(contentType.currentIndex(), i);
@@ -59,7 +59,7 @@ void ContentTypeWidgetTest::shouldEmitSignalWhenIndexChanged()
 {
     PimCommon::ContentTypeWidget contentType;
     contentType.show();
-    QTest::qWaitForWindowExposed(&contentType);
+    QVERIFY(QTest::qWaitForWindowExposed(&contentType));
     QSignalSpy spy(&contentType, SIGNAL(activated(int)));
     contentType.setCurrentIndex(1);
     //FIXME
@@ -70,8 +70,8 @@ void ContentTypeWidgetTest::shouldChangeItem()
 {
     PimCommon::ContentTypeWidget contentType;
     contentType.show();
-    QTest::qWaitForWindowExposed(&contentType);
-    KComboBox *combo = contentType.findChild<KComboBox *>(QStringLiteral("contentcombobox"));
+    QVERIFY(QTest::qWaitForWindowExposed(&contentType));
+    QComboBox *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     for (int i = 0; i < combo->count(); ++i) {
         contentType.setCurrentIndex(i);
         QCOMPARE(contentType.currentText(), combo->currentText());
