@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ void PluginInterface::createPluginInterface()
         qCWarning(PIMCOMMONAKONADI_LOG) << "Missing action collection";
         return;
     }
-    Q_FOREACH (PimCommon::GenericPlugin *plugin, d->mGenericPluginManager->pluginsList()) {
+    for (PimCommon::GenericPlugin *plugin : d->mGenericPluginManager->pluginsList()) {
         if (plugin->isEnabled()) {
             PimCommon::GenericPluginInterface *interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(this));
             interface->setParentWidget(d->mParentWidget);
